@@ -17,7 +17,6 @@ use Modern::Perl;
 use Test::More;
 use Mojo::IOLoop;
 use Encode;
-use Encode::Locale;
 
 our $port = Mojo::IOLoop::Server->generate_port;
 our $pid = fork();
@@ -29,8 +28,11 @@ END {
   }
 }
 
+my $state;
+
 sub process {
   my ($stream, $line) = @_;
+  diag $line unless $state;
   if ($line =~ /^quit$/i) {
     $stream->write("205 goodbye.\r\n" => sub { $stream->close_gracefully });
   } elsif ($line =~ /^mode reader$/i) {
@@ -73,6 +75,20 @@ sub process {
     $stream->write("A program from the nineties\r\n");
     $stream->write("Church bells are ringing\r\n");
     $stream->write(".\r\n");
+  } elsif ($line =~ /^AUTHINFO USER alex$/i) {
+    $stream->write("381 Enter passphrase\r\n");
+  } elsif ($line =~ /^AUTHINFO PASS test$/i) {
+    $stream->write("281 Authentication accepted\r\n");
+  } elsif ($line =~ /^POST$/i) {
+    $stream->write("340 Input article; end with <CR-LF>.<CR-LF>\r\n");
+    $state = 'POST';
+  } elsif ($state eq 'POST') {
+    if ($line eq '.') {
+      $state = undef;
+      $stream->write("240 Article received OK\r\n");
+    } else {
+      # post itself gets ignored
+    }
   } else {
     diag("Unhandled: $line");
   }
@@ -89,7 +105,6 @@ if (!defined $pid) {
     $stream->write("200 test server ready - posting ok\r\n");
     $stream->on(read => sub {
       my ($stream, $bytes) = @_;
-      diag "Received $bytes";
       $buffer .= $bytes;
       while ($buffer =~ /(.*?)\r\n/) {
         process($stream, $1);
